--- layout: template title: API - pyatv.storage.file_storage permalink: /api/storage/file_storage/ link_group: api ---

# Module `pyatv.storage.file_storage`

File based storage module.

Browse git

## Classes

`class FileStorage (filename: str, loop: asyncio.events.AbstractEventLoop)`

  Storage module storing settings in a file.

  Initialize a new FileStorage instance.

  Browse git

  ### Ancestors

  - AbstractStorage
  - Storage
  - abc.ABC

  ### Static methods

  `def default_storage(loop: asyncio.events.AbstractEventLoop) -> FileStorage`

    Return file storage with default path.

    This corresponds to the default file storage path that pyatv uses internally, e.g. in atvremote. Use this if you want to hook into that storage in your own applications.

    The path used for this file is $HOME/.pyatv.conf (C:\Users\.pyatv.conf on Windows).

  ### Inherited members

  - `AbstractStorage`:
    - `changed`
    - `get_settings`
    - `load`
    - `mark_as_saved`
    - `remove_settings`
    - `save`
    - `settings`
    - `storage_model`
    - `update_settings`